% Script for T1 segmentation
% Sung-Ho Woo. 2018. 01. 15
clearvars; clc;
%%% User speficified variables %%%
SPMdir = ['/usr/local/MATLAB/R2022a/toolbox/spm12/']; % Your SPM directory
DataDir = ['/media/sf_Common/PMRI/SG25_24/NIFTI/'];% Directory of your T1 image
T1DataName = [DataDir 'bSG25_24_T1.nii']; % your T1 image name
T2DataName = [DataDir 'rbSG25_24_T2.nii']; % your T2 image name
T1BrainName = [DataDir 'bbSG25_24_T1.nii']; % Skull stripped T1 image
Bthresh = 0.3; % Threshold for tissue segmentation
TPM1 = [SPMdir 'tpm/TPM.nii,1'];% GM
TPM2 = [SPMdir 'tpm/TPM.nii,2'];% WM
TPM3 = [SPMdir 'tpm/TPM.nii,3'];% CSF
TPM4 = [SPMdir 'tpm/TPM.nii,4'];
TPM5 = [SPMdir 'tpm/TPM.nii,5'];
TPM6 = [SPMdir 'tpm/TPM.nii,6'];
saveSegName = [DataDir 'Segmentation_Results.mat'];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
tic;
spm('defaults', 'fMRI')
matlabbatch{1}.spm.spatial.preproc.channel(1).vols = {T1DataName};
matlabbatch{1}.spm.spatial.preproc.channel(1).biasreg = 0.001;
matlabbatch{1}.spm.spatial.preproc.channel(1).biasfwhm = 60;
matlabbatch{1}.spm.spatial.preproc.channel(1).write = [1 1];
matlabbatch{1}.spm.spatial.preproc.channel(2).vols = {T2DataName};
matlabbatch{1}.spm.spatial.preproc.channel(2).biasreg = 0.001;
matlabbatch{1}.spm.spatial.preproc.channel(2).biasfwhm = 60;
matlabbatch{1}.spm.spatial.preproc.channel(2).write = [1 1];
matlabbatch{1}.spm.spatial.preproc.tissue(1).tpm = {TPM1};
matlabbatch{1}.spm.spatial.preproc.tissue(1).ngaus = 1;
matlabbatch{1}.spm.spatial.preproc.tissue(1).native = [1 0];
matlabbatch{1}.spm.spatial.preproc.tissue(1).warped = [1 1];
matlabbatch{1}.spm.spatial.preproc.tissue(2).tpm = {TPM2};
matlabbatch{1}.spm.spatial.preproc.tissue(2).ngaus = 1;
matlabbatch{1}.spm.spatial.preproc.tissue(2).native = [1 0];
matlabbatch{1}.spm.spatial.preproc.tissue(2).warped = [1 1];
matlabbatch{1}.spm.spatial.preproc.tissue(3).tpm = {TPM3};
matlabbatch{1}.spm.spatial.preproc.tissue(3).ngaus = 2;
matlabbatch{1}.spm.spatial.preproc.tissue(3).native = [1 0];
matlabbatch{1}.spm.spatial.preproc.tissue(3).warped = [1 1];
matlabbatch{1}.spm.spatial.preproc.tissue(4).tpm = {TPM4};
matlabbatch{1}.spm.spatial.preproc.tissue(4).ngaus = 3;
matlabbatch{1}.spm.spatial.preproc.tissue(4).native = [1 0];
matlabbatch{1}.spm.spatial.preproc.tissue(4).warped = [1 1];
matlabbatch{1}.spm.spatial.preproc.tissue(5).tpm = {TPM5};
matlabbatch{1}.spm.spatial.preproc.tissue(5).ngaus = 4;
matlabbatch{1}.spm.spatial.preproc.tissue(5).native = [1 0];
matlabbatch{1}.spm.spatial.preproc.tissue(5).warped = [1 1];
matlabbatch{1}.spm.spatial.preproc.tissue(6).tpm = {TPM6};
matlabbatch{1}.spm.spatial.preproc.tissue(6).ngaus = 2;
matlabbatch{1}.spm.spatial.preproc.tissue(6).native = [1 0];
matlabbatch{1}.spm.spatial.preproc.tissue(6).warped = [1 1];
matlabbatch{1}.spm.spatial.preproc.warp.mrf = 0;
matlabbatch{1}.spm.spatial.preproc.warp.cleanup = 0;
matlabbatch{1}.spm.spatial.preproc.warp.reg = [0 0.001 0.5 0.05 0.2];
matlabbatch{1}.spm.spatial.preproc.warp.affreg = 'mni';
matlabbatch{1}.spm.spatial.preproc.warp.fwhm = 0;
matlabbatch{1}.spm.spatial.preproc.warp.samp = 3 ;% sampling distance
matlabbatch{1}.spm.spatial.preproc.warp.write = [1 1];
%spm_jobman('run', matlabbatch);
V = spm_vol(T1DataName);
BrainMask = zeros(V.dim);
Cname = dir([DataDir 'c*.nii']);
for i = 1:3
    V = spm_vol([DataDir Cname(i).name]);
    [cy, xyz] = spm_read_vols(V);
    cindex = find(cy > Bthresh);
    BrainMask(cindex) = 1;
end
TempV = V;
TempV.fname = [DataDir 'BrainMask.nii'];
spm_write_vol(TempV, BrainMask);
V = spm_vol(T1DataName);
[Y, XYZ] = spm_read_vols(V);
T1Brain = Y.*BrainMask;
TempV = V;
TempV.fname = T1BrainName;
spm_write_vol(TempV, T1Brain);
toc
